(*:Package Version: 1.01 *)

(*:Version History: 1.01 (2010.12.18 - xxxx.xx.xx) *)

(*:Copyright: Copyright 2010.12-2010.12, Souitirou Ikebe *)

(*:Author: Souitirou Ikebe *)

(*:Name: EllipticSpecialFunctions`EllipticElementaryFunction` *)

(*:Title: EllipticElementaryFunction *)

(*:Keywords: EllipticShiftedFactorial, EllipticGamma, 
  EllipticBeta *)

(*:Summary:
 
  This package implements some standard elementary 
  functions from elliptic discrete Analysis. 
  It's elliptic shifted factorial, elliptic discrete gamma 
  function and other rerated functions.
*)

(*******************************************************************)





BeginPackage["EllipticSpecialFunctions`EllipticElementaryFunction`",
"QSpecialFunctions`QElementaryFunction`"]





EllipticShiftedFactorial::usage =
"EllipticShiftedFactorial[a,{q0,q1}] gives the elliptic 
 shifted factorial.
 It's evaluated of Product[Product[(1-a q^m q^n),{m,0,infinity}],
 {n,0,infinity}]."

EllipticGamma::usage =
"EllipticGamma[z,{t0,t1}] gives the elliptic discrete function.
 It's the elliptic discrete of the gamma function."

EllipticBeta::usage =
"EllipticBeta[z,w,{t0,t1}] gives the elliptic discrete of the 
 beta function."





Begin["EllipticSpecialFunctions`EllipticElementaryFunction`Private`"]




(*
Attributes[EllipticShiftedFactorial]={Listable}

Attributes[EllipticGamma]={Listable}

Attributes[EllipticBeta]={Listable}
*)




(*******************************************************************)
(*               EllipticShiftedFactorial[a,{q0,q1}]               *)
(*******************************************************************)

EllipticShiftedFactorial[a_,{q0_,q1_}]:=
  Module[{s=1,so=-1,k1=1,qf0},qf0=1;
    While[k1<300,so=s;
        s*=QShiftedFactorial[a*qf0,q1,Infinity];
        qf0*=q0;k1++];s]/;
        (Precision[a]<Infinity && Abs[q0]<1 && Abs[q1]<1)



(*******************************************************************)
(*                    EllipticGamma[z,{t0,t1}]                     *)
(*******************************************************************)

EllipticGamma[z_,{tau0_,tau1_}]:=
  Module[{zf=Exp[2 Pi I z],
          q0f=Exp[2 Pi I tau0],q1f=Exp[2 Pi I tau1]},
      EllipticShiftedFactorial[q0f*q1f/zf,{q0f,q1f}]/
      EllipticShiftedFactorial[zf,{q0f,q1f}]]/;
      (Precision[z]<Infinity)

(*

EllipticGamma[z_,{q0_,q1_}]:=
  Module[{zf=Exp[2 Pi I z]},
      EllipticShiftedFactorial[q0*q1/zf,{q0,q1}]/
      EllipticShiftedFactorial[zf,{q0,q1}]]/;
      (Precision[z]<Infinity)

*)


(*******************************************************************)
(*                    EllipticBeta[z,w,{t0,t1}]                    *)
(*******************************************************************)

EllipticBeta[z_,w_,{tau0_,tau1_}]:=
  EllipticGamma[z,{tau0,tau1}]*EllipticGamma[w,{tau0,tau1}]/
  EllipticGamma[z+w,{tau0,tau1}];



(*******************************************************************)

End[]

Protect[EllipticShiftedFactorial, EllipticGamma, 
  EllipticBeta]

EndPackage[]